import { BeforeInsert, Column, Entity, PrimaryGeneratedColumn, Unique } from 'typeorm';
import bcrypt from 'bcrypt';

@Entity('users')
@Unique(['username'])
export class User {
  @PrimaryGeneratedColumn()
  id!: number;

  @Column()
  username!: string;

  @Column()
  password?: string;

  @Column()
  displayName!: string;

  @Column()
  token!: string;

  @Column({ default: 'user' })
  role!: 'user' | 'admin';

  async comparePassword(password: string): Promise<boolean> {
    if (this.password) return await bcrypt.compare(password, this.password);
    return false;
  }

  generateToken() {
    this.token = crypto.randomUUID();
  }

  @BeforeInsert()
  async hashPassword() {
    const SALT_WORK_FACTORY = 10;
    if (this.password) {
      const salt = await bcrypt.genSalt(SALT_WORK_FACTORY);
      const hashedPassword = await bcrypt.hash(this.password, salt);
      this.password = hashedPassword;
    }
  }
}
