import { IRoute } from '@/interfaces/IRoute.interface';
import { Router } from 'express';
import { AuthController } from '@/controllers/auth.controller';
import { authValidate } from '@/middlewares/authValidate';

export class AuthRoute implements IRoute {
  public path = '/auth';
  public router = Router();
  private controller: AuthController;

  constructor() {
    this.controller = new AuthController();
    this.init();
  }

  private init() {
    this.router.post('/register', this.controller.register);
    this.router.post('/sign-in', this.controller.signIn);
    this.router.get('/secret', this.controller.secret);
    this.router.delete('/logout', authValidate, this.controller.logout);
  }
}
