import { Router } from 'express';
import { IRoute } from '@/interfaces/IRoute.interface';
import { ProductController } from '@/controllers/product.controller';
import { upload } from '@/middlewares/upload';
import { authValidate } from '@/middlewares/authValidate';
import { checkRole } from '@/middlewares/checkRole';

export class ProductRoute implements IRoute {
  public path = '/products';
  public router = Router();
  private controller: ProductController;

  constructor() {
    this.controller = new ProductController();
    this.init();
  }

  private init() {
    this.router.get('/', this.controller.getProducts);
    this.router.get('/:id', this.controller.getProduct);
    this.router.post('/', authValidate, checkRole('admin'), upload.single('image'), this.controller.createProduct);
  }
}
