import { IProduct } from '@/interfaces/IProduct.interface';
import { ProductDto } from '@/dto/product.dto';
import { ProductRepository } from '@/repositories/product.repository';
import { validate } from 'class-validator';
import { formatErrors } from '@/helpers/formatErrors';

export class ProductService {
  private repository: ProductRepository;

  constructor() {
    this.repository = new ProductRepository();
  }

  public async getProducts(): Promise<IProduct[]> {
    return await this.repository.getProducts();
  }

  public async getProduct(id: number): Promise<IProduct> {
    const product = await this.repository.getProduct(id);
    if (product) return product;
    else throw new Error('Invalid id');
  }

  public async createProduct(productDto: ProductDto): Promise<IProduct> {
    const errors = await validate(productDto, { whitelist: true, validationError: { target: false, value: false } });
    if (errors.length) throw formatErrors(errors);
    return await this.repository.createProduct(productDto);
  }
}
